AccountAddressType

Enum AccountAddressType 

pub enum AccountAddressType {
    P2PKH,
    P2SHWPKH,
    P2WPKH,
    P2WSH(u32),
}
Address type an account is using

Variants



P2PKH

legacy pay to public key hash (BIP44)



P2SHWPKH

transitional segwit pay to public key hash in legacy format (BIP49)



P2WPKH

native segwit pay to public key hash in bech format (BIP84)



P2WSH(u32)

native segwit pay to script do not use 44, 49 or 84 for this parameter, to avoid confusion with above types Only supports scripts that can be spent with following witness:

Implementations