pub struct KeyDerivation {
pub account: u32,
pub sub: u32,
pub kix: u32,
pub tweak: Option<Vec<u8>>,
pub csv: Option<u16>,
}Expand description
Key derivation detail information coordinates of a key as defined in BIP32 and BIP44
Fields
account: u32m / purpose’ / coin_type’ / account’ / sub / kix
sub: u32m / purpose’ / coin_type’ / account’ / sub / kix
kix: u32m / purpose’ / coin_type’ / account’ / sub / kix
tweak: Option<Vec<u8>>optional additive tweak to private key
csv: Option<u16>optional number of blocks this can not be spent after confirmation (OP_CSV)